# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/notification.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n opus_protobuf/notification.proto\x12\x0cnotification\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1aopus_protobuf/common.proto\":\n\x1eSendValidationCodeEmailRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"O\n\x1cSendTalentOpportunityRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06talent\x18\x02 \x01(\t\x12\x13\n\x0bopportunity\x18\x03 \x01(\t\"$\n\x14SendCsvReportRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"L\n!SendInquireByCulturalAlertRequest\x12\x0f\n\x07\x63ompany\x18\x01 \x01(\t\x12\x16\n\x0e\x63ultural_alert\x18\x02 \x01(\t\"\xab\x01\n\'SendOpportunityEmailNotificationRequest\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07subject\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06\x65mails\x18\x03 \x03(\t\x12\x11\n\x04\x62ody\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04html\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_subjectB\x07\n\x05_bodyB\x07\n\x05_html2\xe6\x04\n\x16NotificationController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x12\x42\n\x17SendForgotPasswordEmail\x12\x13.common.GetItemByID\x1a\x10.common.Response\"\x00\x12[\n\x17SendValidationCodeEmail\x12,.notification.SendValidationCodeEmailRequest\x1a\x10.common.Response\"\x00\x12W\n\x15SendTalentOpportunity\x12*.notification.SendTalentOpportunityRequest\x1a\x10.common.Response\"\x00\x12G\n\rSendCsvReport\x12\".notification.SendCsvReportRequest\x1a\x10.common.Response\"\x00\x12\x61\n\x1aSendInquireByCulturalAlert\x12/.notification.SendInquireByCulturalAlertRequest\x1a\x10.common.Response\"\x00\x12m\n SendOpportunityEmailNotification\x12\x35.notification.SendOpportunityEmailNotificationRequest\x1a\x10.common.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.notification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SENDVALIDATIONCODEEMAILREQUEST']._serialized_start=107
  _globals['_SENDVALIDATIONCODEEMAILREQUEST']._serialized_end=165
  _globals['_SENDTALENTOPPORTUNITYREQUEST']._serialized_start=167
  _globals['_SENDTALENTOPPORTUNITYREQUEST']._serialized_end=246
  _globals['_SENDCSVREPORTREQUEST']._serialized_start=248
  _globals['_SENDCSVREPORTREQUEST']._serialized_end=284
  _globals['_SENDINQUIREBYCULTURALALERTREQUEST']._serialized_start=286
  _globals['_SENDINQUIREBYCULTURALALERTREQUEST']._serialized_end=362
  _globals['_SENDOPPORTUNITYEMAILNOTIFICATIONREQUEST']._serialized_start=365
  _globals['_SENDOPPORTUNITYEMAILNOTIFICATIONREQUEST']._serialized_end=536
  _globals['_NOTIFICATIONCONTROLLER']._serialized_start=539
  _globals['_NOTIFICATIONCONTROLLER']._serialized_end=1153
# @@protoc_insertion_point(module_scope)
