# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2
from opus_protobuf import statistic_pb2 as opus__protobuf_dot_statistic__pb2


class StatisticControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HealthCheck = channel.unary_unary(
                '/statistic.StatisticController/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Health.FromString,
                )
        self.uploadSkuPicture = channel.unary_unary(
                '/statistic.StatisticController/uploadSkuPicture',
                request_serializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UserConnectAyrshare = channel.unary_unary(
                '/statistic.StatisticController/UserConnectAyrshare',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.GetInstagramInfo = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramInfo',
                request_serializer=opus__protobuf_dot_statistic__pb2.DataRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.GetInstagramFollowers = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramFollowers',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramFollows = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramFollows',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramAudienceGender = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramAudienceGender',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramAudienceCity = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramAudienceCity',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramAudienceCountry = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramAudienceCountry',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramReach = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramReach',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramInteractions = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramInteractions',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramLikes = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramLikes',
                request_serializer=opus__protobuf_dot_statistic__pb2.GetInstagramLikesRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.GetInstagramEngagementRate = channel.unary_unary(
                '/statistic.StatisticController/GetInstagramEngagementRate',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
                )
        self.UpdateSocialNetwork = channel.unary_unary(
                '/statistic.StatisticController/UpdateSocialNetwork',
                request_serializer=opus__protobuf_dot_statistic__pb2.DataRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.CreateAudienceInstagram = channel.unary_unary(
                '/statistic.StatisticController/CreateAudienceInstagram',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.CalculateMean = channel.unary_unary(
                '/statistic.StatisticController/CalculateMean',
                request_serializer=opus__protobuf_dot_statistic__pb2.CalculateMeanRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadBrandPicture = channel.unary_unary(
                '/statistic.StatisticController/UploadBrandPicture',
                request_serializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadOpportunityImage = channel.unary_unary(
                '/statistic.StatisticController/UploadOpportunityImage',
                request_serializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadOpportunityTreatment = channel.unary_unary(
                '/statistic.StatisticController/UploadOpportunityTreatment',
                request_serializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadInterestPicture = channel.unary_unary(
                '/statistic.StatisticController/UploadInterestPicture',
                request_serializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.LinkTikTok = channel.unary_unary(
                '/statistic.StatisticController/LinkTikTok',
                request_serializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.LinkTensorSocial = channel.unary_unary(
                '/statistic.StatisticController/LinkTensorSocial',
                request_serializer=opus__protobuf_dot_statistic__pb2.LinkTensorSocialRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.ReadCsvUser = channel.unary_unary(
                '/statistic.StatisticController/ReadCsvUser',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadCoverListPicture = channel.unary_unary(
                '/statistic.StatisticController/UploadCoverListPicture',
                request_serializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.TalentUpdateOne = channel.unary_unary(
                '/statistic.StatisticController/TalentUpdateOne',
                request_serializer=opus__protobuf_dot_statistic__pb2.TalentProfile.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.ResyncAllUsers = channel.unary_unary(
                '/statistic.StatisticController/ResyncAllUsers',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )


class StatisticControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def uploadSkuPicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserConnectAyrshare(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramFollowers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramFollows(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramAudienceGender(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramAudienceCity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramAudienceCountry(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramReach(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramInteractions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramLikes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstagramEngagementRate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSocialNetwork(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAudienceInstagram(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CalculateMean(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadBrandPicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadOpportunityImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadOpportunityTreatment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadInterestPicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LinkTikTok(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LinkTensorSocial(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadCsvUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadCoverListPicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TalentUpdateOne(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResyncAllUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StatisticControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Health.SerializeToString,
            ),
            'uploadSkuPicture': grpc.unary_unary_rpc_method_handler(
                    servicer.uploadSkuPicture,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UserConnectAyrshare': grpc.unary_unary_rpc_method_handler(
                    servicer.UserConnectAyrshare,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'GetInstagramInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramInfo,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.DataRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'GetInstagramFollowers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramFollowers,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramFollows': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramFollows,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramAudienceGender': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramAudienceGender,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramAudienceCity': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramAudienceCity,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramAudienceCountry': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramAudienceCountry,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramReach': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramReach,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramInteractions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramInteractions,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramLikes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramLikes,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.GetInstagramLikesRequest.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'GetInstagramEngagementRate': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstagramEngagementRate,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.SerializeToString,
            ),
            'UpdateSocialNetwork': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSocialNetwork,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.DataRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'CreateAudienceInstagram': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAudienceInstagram,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'CalculateMean': grpc.unary_unary_rpc_method_handler(
                    servicer.CalculateMean,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.CalculateMeanRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadBrandPicture': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadBrandPicture,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadOpportunityImage': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadOpportunityImage,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadOpportunityTreatment': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadOpportunityTreatment,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadInterestPicture': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadInterestPicture,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'LinkTikTok': grpc.unary_unary_rpc_method_handler(
                    servicer.LinkTikTok,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.AccessInstagram.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'LinkTensorSocial': grpc.unary_unary_rpc_method_handler(
                    servicer.LinkTensorSocial,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.LinkTensorSocialRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'ReadCsvUser': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadCsvUser,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadCoverListPicture': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadCoverListPicture,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.UploadPictureRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'TalentUpdateOne': grpc.unary_unary_rpc_method_handler(
                    servicer.TalentUpdateOne,
                    request_deserializer=opus__protobuf_dot_statistic__pb2.TalentProfile.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'ResyncAllUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ResyncAllUsers,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'statistic.StatisticController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StatisticController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_common__pb2.Health.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def uploadSkuPicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/uploadSkuPicture',
            opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserConnectAyrshare(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UserConnectAyrshare',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramInfo',
            opus__protobuf_dot_statistic__pb2.DataRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramFollowers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramFollowers',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramFollows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramFollows',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramAudienceGender(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramAudienceGender',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramAudienceCity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramAudienceCity',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramAudienceCountry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramAudienceCountry',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramReach(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramReach',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramInteractions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramInteractions',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramLikes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramLikes',
            opus__protobuf_dot_statistic__pb2.GetInstagramLikesRequest.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstagramEngagementRate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/GetInstagramEngagementRate',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_statistic__pb2.InstagramControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSocialNetwork(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UpdateSocialNetwork',
            opus__protobuf_dot_statistic__pb2.DataRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAudienceInstagram(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/CreateAudienceInstagram',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CalculateMean(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/CalculateMean',
            opus__protobuf_dot_statistic__pb2.CalculateMeanRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadBrandPicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UploadBrandPicture',
            opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadOpportunityImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UploadOpportunityImage',
            opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadOpportunityTreatment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UploadOpportunityTreatment',
            opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadInterestPicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UploadInterestPicture',
            opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LinkTikTok(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/LinkTikTok',
            opus__protobuf_dot_statistic__pb2.AccessInstagram.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LinkTensorSocial(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/LinkTensorSocial',
            opus__protobuf_dot_statistic__pb2.LinkTensorSocialRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadCsvUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/ReadCsvUser',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadCoverListPicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/UploadCoverListPicture',
            opus__protobuf_dot_statistic__pb2.UploadPictureRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TalentUpdateOne(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/TalentUpdateOne',
            opus__protobuf_dot_statistic__pb2.TalentProfile.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResyncAllUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/statistic.StatisticController/ResyncAllUsers',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
