# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2
from opus_protobuf import notification_pb2 as opus__protobuf_dot_notification__pb2


class NotificationControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HealthCheck = channel.unary_unary(
                '/notification.NotificationController/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Health.FromString,
                )
        self.SendForgotPasswordEmail = channel.unary_unary(
                '/notification.NotificationController/SendForgotPasswordEmail',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.SendValidationCodeEmail = channel.unary_unary(
                '/notification.NotificationController/SendValidationCodeEmail',
                request_serializer=opus__protobuf_dot_notification__pb2.SendValidationCodeEmailRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.SendTalentOpportunity = channel.unary_unary(
                '/notification.NotificationController/SendTalentOpportunity',
                request_serializer=opus__protobuf_dot_notification__pb2.SendTalentOpportunityRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.SendCsvReport = channel.unary_unary(
                '/notification.NotificationController/SendCsvReport',
                request_serializer=opus__protobuf_dot_notification__pb2.SendCsvReportRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.SendInquireByCulturalAlert = channel.unary_unary(
                '/notification.NotificationController/SendInquireByCulturalAlert',
                request_serializer=opus__protobuf_dot_notification__pb2.SendInquireByCulturalAlertRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.SendOpportunityEmailNotification = channel.unary_unary(
                '/notification.NotificationController/SendOpportunityEmailNotification',
                request_serializer=opus__protobuf_dot_notification__pb2.SendOpportunityEmailNotificationRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )


class NotificationControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendForgotPasswordEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendValidationCodeEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendTalentOpportunity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendCsvReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendInquireByCulturalAlert(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendOpportunityEmailNotification(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NotificationControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Health.SerializeToString,
            ),
            'SendForgotPasswordEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.SendForgotPasswordEmail,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'SendValidationCodeEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.SendValidationCodeEmail,
                    request_deserializer=opus__protobuf_dot_notification__pb2.SendValidationCodeEmailRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'SendTalentOpportunity': grpc.unary_unary_rpc_method_handler(
                    servicer.SendTalentOpportunity,
                    request_deserializer=opus__protobuf_dot_notification__pb2.SendTalentOpportunityRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'SendCsvReport': grpc.unary_unary_rpc_method_handler(
                    servicer.SendCsvReport,
                    request_deserializer=opus__protobuf_dot_notification__pb2.SendCsvReportRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'SendInquireByCulturalAlert': grpc.unary_unary_rpc_method_handler(
                    servicer.SendInquireByCulturalAlert,
                    request_deserializer=opus__protobuf_dot_notification__pb2.SendInquireByCulturalAlertRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'SendOpportunityEmailNotification': grpc.unary_unary_rpc_method_handler(
                    servicer.SendOpportunityEmailNotification,
                    request_deserializer=opus__protobuf_dot_notification__pb2.SendOpportunityEmailNotificationRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'notification.NotificationController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NotificationController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_common__pb2.Health.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendForgotPasswordEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/SendForgotPasswordEmail',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendValidationCodeEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/SendValidationCodeEmail',
            opus__protobuf_dot_notification__pb2.SendValidationCodeEmailRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendTalentOpportunity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/SendTalentOpportunity',
            opus__protobuf_dot_notification__pb2.SendTalentOpportunityRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendCsvReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/SendCsvReport',
            opus__protobuf_dot_notification__pb2.SendCsvReportRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendInquireByCulturalAlert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/SendInquireByCulturalAlert',
            opus__protobuf_dot_notification__pb2.SendInquireByCulturalAlertRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendOpportunityEmailNotification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/notification.NotificationController/SendOpportunityEmailNotification',
            opus__protobuf_dot_notification__pb2.SendOpportunityEmailNotificationRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
