# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/statistic.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dopus_protobuf/statistic.proto\x12\tstatistic\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1aopus_protobuf/common.proto\"e\n\x14UploadPictureRequest\x12\x13\n\x06userId\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\n\n\x02id\x18\x02 \x01(\t\x12!\n\x07picture\x18\x03 \x01(\x0b\x32\x10.common.DocumentB\t\n\x07_userId\"\x1b\n\x0b\x44\x61taRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\x82\x01\n\x0f\x41\x63\x63\x65ssInstagram\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x0f\n\x02id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04user\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03url\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x05 \x01(\tB\x05\n\x03_idB\x07\n\x05_userB\x06\n\x04_url\"_\n\x1bInstagramControllerResponse\x12-\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1f.statistic.InstagramApiResponse\x12\x11\n\thave_mean\x18\x02 \x01(\x08\"[\n\x14InstagramApiResponse\x12\r\n\x05value\x18\x01 \x01(\x05\x12\x10\n\x08metadata\x18\x02 \x01(\t\x12\x15\n\x08\x65nd_time\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_end_time\"b\n\x18GetInstagramLikesRequest\x12(\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1a.statistic.AccessInstagram\x12\x12\n\x05\x62roke\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\x08\n\x06_broke\"C\n\x14\x43\x61lculateMeanRequest\x12\x0c\n\x04mean\x18\x01 \x01(\x05\x12\x12\n\nnew_sample\x18\x02 \x01(\x05\x12\t\n\x01n\x18\x03 \x01(\x05\"\xce\x01\n\x17LinkTensorSocialRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\x12\x0e\n\x06tenant\x18\x05 \x01(\t\x12\x10\n\x08industry\x18\x06 \x01(\t\x12\x18\n\x10industry_segment\x18\x07 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x08 \x01(\t\x12\x10\n\x08\x62irthday\x18\t \x01(\t\x12\x0c\n\x04\x63ity\x18\n \x01(\t\"\x8c\x01\n\rTalentProfile\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x0e\n\x06tenant\x18\x03 \x01(\t\x12\x10\n\x08industry\x18\x04 \x01(\t\x12\x10\n\x08\x62irthday\x18\x05 \x01(\t\x12\x18\n\x10industry_segment\x18\x06 \x01(\t\x12\x0e\n\x06gender\x18\x07 \x01(\t2\x9f\x10\n\x13StatisticController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x12G\n\x10uploadSkuPicture\x12\x1f.statistic.UploadPictureRequest\x1a\x10.common.Response\"\x00\x12>\n\x13UserConnectAyrshare\x12\x13.common.GetItemByID\x1a\x10.common.Response\"\x00\x12>\n\x10GetInstagramInfo\x12\x16.statistic.DataRequest\x1a\x10.common.Response\"\x00\x12]\n\x15GetInstagramFollowers\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12[\n\x13GetInstagramFollows\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12\x62\n\x1aGetInstagramAudienceGender\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12`\n\x18GetInstagramAudienceCity\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12\x63\n\x1bGetInstagramAudienceCountry\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12Y\n\x11GetInstagramReach\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12`\n\x18GetInstagramInteractions\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12\x62\n\x11GetInstagramLikes\x12#.statistic.GetInstagramLikesRequest\x1a&.statistic.InstagramControllerResponse\"\x00\x12\x62\n\x1aGetInstagramEngagementRate\x12\x1a.statistic.AccessInstagram\x1a&.statistic.InstagramControllerResponse\"\x00\x12\x41\n\x13UpdateSocialNetwork\x12\x16.statistic.DataRequest\x1a\x10.common.Response\"\x00\x12I\n\x17\x43reateAudienceInstagram\x12\x1a.statistic.AccessInstagram\x1a\x10.common.Response\"\x00\x12\x44\n\rCalculateMean\x12\x1f.statistic.CalculateMeanRequest\x1a\x10.common.Response\"\x00\x12I\n\x12UploadBrandPicture\x12\x1f.statistic.UploadPictureRequest\x1a\x10.common.Response\"\x00\x12M\n\x16UploadOpportunityImage\x12\x1f.statistic.UploadPictureRequest\x1a\x10.common.Response\"\x00\x12Q\n\x1aUploadOpportunityTreatment\x12\x1f.statistic.UploadPictureRequest\x1a\x10.common.Response\"\x00\x12L\n\x15UploadInterestPicture\x12\x1f.statistic.UploadPictureRequest\x1a\x10.common.Response\"\x00\x12<\n\nLinkTikTok\x12\x1a.statistic.AccessInstagram\x1a\x10.common.Response\"\x00\x12J\n\x10LinkTensorSocial\x12\".statistic.LinkTensorSocialRequest\x1a\x10.common.Response\"\x00\x12\x33\n\x0bReadCsvUser\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12M\n\x16UploadCoverListPicture\x12\x1f.statistic.UploadPictureRequest\x1a\x10.common.Response\"\x00\x12?\n\x0fTalentUpdateOne\x12\x18.statistic.TalentProfile\x1a\x10.common.Response\"\x00\x12<\n\x0eResyncAllUsers\x12\x16.google.protobuf.Empty\x1a\x10.common.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.statistic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UPLOADPICTUREREQUEST']._serialized_start=101
  _globals['_UPLOADPICTUREREQUEST']._serialized_end=202
  _globals['_DATAREQUEST']._serialized_start=204
  _globals['_DATAREQUEST']._serialized_end=231
  _globals['_ACCESSINSTAGRAM']._serialized_start=234
  _globals['_ACCESSINSTAGRAM']._serialized_end=364
  _globals['_INSTAGRAMCONTROLLERRESPONSE']._serialized_start=366
  _globals['_INSTAGRAMCONTROLLERRESPONSE']._serialized_end=461
  _globals['_INSTAGRAMAPIRESPONSE']._serialized_start=463
  _globals['_INSTAGRAMAPIRESPONSE']._serialized_end=554
  _globals['_GETINSTAGRAMLIKESREQUEST']._serialized_start=556
  _globals['_GETINSTAGRAMLIKESREQUEST']._serialized_end=654
  _globals['_CALCULATEMEANREQUEST']._serialized_start=656
  _globals['_CALCULATEMEANREQUEST']._serialized_end=723
  _globals['_LINKTENSORSOCIALREQUEST']._serialized_start=726
  _globals['_LINKTENSORSOCIALREQUEST']._serialized_end=932
  _globals['_TALENTPROFILE']._serialized_start=935
  _globals['_TALENTPROFILE']._serialized_end=1075
  _globals['_STATISTICCONTROLLER']._serialized_start=1078
  _globals['_STATISTICCONTROLLER']._serialized_end=3157
# @@protoc_insertion_point(module_scope)
